#
# spec file for package utf8proc
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_ver 2
Name:           utf8proc
Version:        2.8.0
Release:        1.4
Summary:        Library for processing UTF-8 encoded Unicode strings
License:        MIT
Group:          System/Libraries
URL:            https://julialang.org/utf8proc/
Source:         https://github.com/JuliaStrings/utf8proc/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
utf8proc is a library for processing UTF-8 encoded Unicode strings.
Some features are Unicode normalization, stripping of default ignorable
characters, case folding and detection of grapheme cluster boundaries.
A special character mapping is available, which converts for example
the characters “Hyphen” (U+2010), “Minus” (U+2212) and “Hyphen-Minus
(U+002D, ASCII Minus) all into the ASCII minus sign, to make them
equal for comparisons.

%package     -n lib%{name}%{lib_ver}
Summary:        Library for processing UTF-8 encoded Unicode strings
Group:          System/Libraries

%description -n lib%{name}%{lib_ver}
utf8proc is a library for processing UTF-8 encoded Unicode strings.
Some features are Unicode normalization, stripping of default ignorable
characters, case folding and detection of grapheme cluster boundaries.
A special character mapping is available, which converts for example
the characters “Hyphen” (U+2010), “Minus” (U+2212) and “Hyphen-Minus
(U+002D, ASCII Minus) all into the ASCII minus sign, to make them
equal for comparisons.

%package        devel
Summary:        Library for processing UTF-8 encoded Unicode strings
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{lib_ver} = %{version}

%description    devel
utf8proc is a library for processing UTF-8 encoded Unicode strings.
Some features are Unicode normalization, stripping of default ignorable
characters, case folding and detection of grapheme cluster boundaries.
A special character mapping is available, which converts for example
the characters “Hyphen” (U+2010), “Minus” (U+2212) and “Hyphen-Minus
(U+002D, ASCII Minus) all into the ASCII minus sign, to make them
equal for comparisons.

This package provides libraries and header files for developing applications
that use utf8proc.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
make %{?_smp_mflags} \
	DESTDIR=%{buildroot} \
	prefix=%{_prefix} \
	libdir=%{_libdir} \
	install
find %{buildroot}/%{_libdir} -type f -name "*.a" -print -delete

%post -n lib%{name}%{lib_ver} -p /sbin/ldconfig
%postun -n lib%{name}%{lib_ver} -p /sbin/ldconfig

%files -n lib%{name}%{lib_ver}
%license LICENSE.md
%doc lump.md NEWS.md README.md
%{_libdir}/libutf8proc.so.*

%files devel
%{_includedir}/utf8proc.h
%{_libdir}/libutf8proc.so
%{_libdir}/pkgconfig/libutf8proc.pc

%changelog
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 2.8.0:
  * Unicode 15 support
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  - Unicode 14 support
  - Support `GNUInstallDirs` in CMake build
  - `cmake` build now installs `pkg-config` file
  - Various build and portability improvements.
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 2.6.1:
  - Bugfix in `utf8proc_grapheme_break_stateful` for `NULL` state argument, which
  also broke `utf8proc_grapheme_break`.
  - New `utf8proc_islower` and `utf8proc_isupper` functions ([#196]).
  - Bugfix for manual calls to `grapheme_break_extended` for initial characters ([#205]).
  - Various build and portability improvements.
* Sat Mar 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- utf8proc 2.5.0:
  * Unicode 13 support
  * No longer report zero width for category Sk
* Wed May 15 2019 Andreas Stieger <andreas.stieger@gmx.de>
- utf8proc 2.4.0:
  * Unicode 12.1 support
  * Fixed incorrect UTF8PROC_VERSION_MINOR version number in header
    and bumped shared-library version
- includes changes from 2.3.0:
  * Unicode 12 support
  * New function utf8proc_unicode_version to return the supported
    Unicode version
  * Simpler character-width computation that no longer uses GNU
    Unifont metrics: East-Asian wide characters have width 2, and
    all other printable characters have width 1
  * Fix CHARBOUND option for utf8proc_map to preserve U+FFFE and
    U+FFFF non-characters
* Wed Aug  8 2018 astieger@suse.com
- utf8proc 2.2.0:
  * Unicode 11 support
  * utf8proc_NFKC_Casefold convenience function for NFKC_Casefold
    normalization
  * UTF8PROC_STRIPNA option to strip unassigned codepoints
  * toupper of ß (U+00df) now yields ẞ (U+1E9E), similar to musl;
    case-folding still yields the standard "ss" mapping.
  * utf8proc_charwidth now returns 1 for U+00AD (soft hyphen) and
    for unassigned/PUA codepoints
  * Fixed a composition bug
* Thu Feb 16 2017 astieger@suse.com
- utf8proc 2.1.0:
  * New functions utf8proc_map_custom and utf8proc_decompose_custom
    to allow user-supplied transformations of codepoints, in
    conjunction with other transformations
  * New function utf8proc_normalize_utf32 to apply normalizations
    directly to UTF-32 data (not just UTF-8)
  * Fixed stack overflow that could occur due to incorrect
    definition of UINT16_MAX with some compilers (boo#1025696)
  * Updated font metrics to use Unifont 9.0.04.
- includes changes from 2.0.2:
  * C89/C99 fixes
- includes changes from 2.0.1:
  * Bug fix in utf8proc_grapheme_break_stateful
- includes changes from 2.0:
  * Updated for Unicode 9.0
  * New utf8proc_grapheme_break_stateful to handle the complicated
    grapheme-breaking rules in Unicode 9. The old
    utf8proc_grapheme_break is still provided, but may incorrectly
    identify grapheme breaks in some Unicode-9 sequences.
  * Smaller Unicode tables
    This required changes in the utf8proc_property_t structure,
    which breaks backward compatibility if struct is accessed
    directly
  * Buffer overrun fix (bsc#1025685)
* Sun Apr 24 2016 astieger@suse.com
- utf8proc 1.3.1:
  * Do not export symbol for internal function unsafe_encode_char()
  * Install relative symbolic links for shared libraries
  * Enable and fix compiler warnings
- remove cmake dependency
* Thu Sep 17 2015 dmitry_r@opensuse.org
- Update to version 1.3
  * Updated for Unicode 8.0, see NEWS.md for more details
* Fri Aug  8 2014 dmitry_r@opensuse.org
- Fix so version
* Wed Jul 23 2014 dmitry_r@opensuse.org
- Initial package, version 1.1.6
